C To calculate the coordinate transformation matrix relating 
C   two crystals of arbitrary structure, from data consisting
C   of a pair of vectors (real or reciprocal) from each crystal.
C   The pair from one crystal has to be parallel to that from 
C   the other crystal. This is useful in studying the orientation
C   relationships between crystals.
C
C This subroutine works for any crystal system.
C 
C Reference
C  Worked Examples in the Geometry of Crystals
C  by H. K. D. H. Bhadeshia
C  Published by the Institute of Materials, London, 1987.
C  See pages 12-18 including Examples 4 and 5.
C

      SUBROUTINE MAP_CRYSTAL_CORD(H1,K1,L1,JR1,H2,K2,L2,JR2,H4,K4,L4,
     &JR4,H5,K5,L5,JR5,C,D,G1,G2)
      IMPLICIT NONE
      REAL G1(9),F1(9),G2(9),F2(9),A(9),B(9),C(9),D(9)
      REAL H1,K1,L1,H2,K2,L2,H3,K3,L3,H4,K4,L4,H5,K5,L5,H6,K6,L6
      REAL M1,M2,M3,M4,M5,M6,KP,GP,MP
      INTEGER JR1,JR2,JR3,JR4,JR5,JR6
C
C F1 and F2 are described as F, and G1 and G2 as G in what follows.
C The metric tensor F converts the components from reciprocal to
C  real space. 
C The metric tensor G converts the components from real to reciprocal
C  space, and G is the inverse of F and vice-versa.
C 
      CALL MAP_UTIL_INVERS(F1,G1)
      CALL MAP_UTIL_INVERS(F2,G2)
C
C Find vector [H3 K3 L3] which is normal to [H1 K1 L1] and [H2 K2 L2]
      CALL MAP_UTIL_CROSS(H1,K1,L1,JR1,H2,K2,L2,JR2,H3,K3,L3,JR3,F1,G1)
C Find vector [H6 K6 L6] which is normal to [H4 K4 L4] and [H5 K5 L5]
      CALL MAP_UTIL_CROSS(H4,K4,L4,JR4,H5,K5,L5,JR5,H6,K6,L6,JR6,F2,G2)
C
C Find the magnitude of each of the six vectors
         CALL MAP_UTIL_MAGG(H1,K1,L1,G1,M1)
         CALL MAP_UTIL_MAGG(H2,K2,L2,G1,M2)
         CALL MAP_UTIL_MAGG(H3,K3,L3,G1,M3)
         CALL MAP_UTIL_MAGG(H4,K4,L4,G2,M4)
         CALL MAP_UTIL_MAGG(H5,K5,L5,G2,M5)
         CALL MAP_UTIL_MAGG(H6,K6,L6,G2,M6)
C
C Hence calculate the normalisation constants
C  see for example, the constants k, g, m on page 17
       KP=M1/M4
       GP=M2/M5
       MP=M3/M6
C
C Calculate the matrices which are manipulated to enable the
C   coordinate transformation matrix D, and its inverse C
C
         A(1)=H1*KP
         A(4)=K1*KP
         A(7)=L1*KP
         A(2)=H2*GP
         A(5)=K2*GP
         A(8)=L2*GP
         A(3)=H3*MP
         A(6)=K3*MP
         A(9)=L3*MP
C 
         B(1)=H4
         B(2)=H5
         B(3)=H6
         B(4)=K4
         B(5)=K5
         B(6)=K6
         B(7)=L4
         B(8)=L5
         B(9)=L6
C
      CALL MAP_UTIL_INVERS(C,B)
      CALL MAP_UTIL_PROD(D,A,C)
C
      CALL MAP_UTIL_INVERS(C,D)
C
C
      RETURN
      END
